as_ggplot() takes an scplot object as input and returns a ggplot2 object.

as_ggplot(scplot)

Arguments

scplot

An scplot object.

Value

A ggplot2 plot object.

Details

as_ggplot() is used directly when you want to return a ggplot2 object for further use with external ggplot functions. It is also used internally when printing an scplot object (see print.scplot()). The function processes the data and theme specifications from the scplot object and constructs a ggplot2 plot accordingly.

Author

Juergen Wilbert