scplot() objectas_ggplot.Rdas_ggplot() takes an scplot object as input and returns a ggplot2
object.
as_ggplot(scplot)A ggplot2 plot object.
as_ggplot() is used directly when you want to return a ggplot2 object for
further use with external ggplot functions.
It is also used internally when printing an scplot object (see print.scplot()).
The function processes the data and theme specifications from the scplot object and constructs a ggplot2 plot accordingly.